KeysIterator

Struct KeysIterator 

pub struct KeysIterator<'a> { /* private fields */ }
Structure to iterate through key names in KeyedMessage.

Mainly useful to discover what keys are present inside the message.

Implements FallibleIterator providing similar functionality to classic Iterator. FallibleIterator is used because internal ecCodes functions can return internal error in some edge-cases. The usage of FallibleIterator is sligthly different than usage of Iterator, check the documentation for more details.

To discover key contents you need to read_key with name given by the iterator.

Example

 use eccodes::{ProductKind, CodesHandle, KeyedMessage, KeysIteratorFlags};
 use eccodes::{FallibleIterator, FallibleStreamingIterator};
 let file_path = Path::new("./data/iceland.grib");
 let product_kind = ProductKind::GRIB;
  
 let mut handle = CodesHandle::new_from_file(file_path, product_kind)?;
 let current_message = handle.next()?.context("no message")?;
  
 let mut keys_iter = current_message.default_keys_iterator()?;
  
 while let Some(key_name) = keys_iter.next()? {
     println!("{key_name}");
 }

Errors

The next() method will return CodesInternal when internal ecCodes function returns non-zero code.